;;*****************************************************************************
;;*****************************************************************************
;;  FILENAME: FlashTemp.asm
;;   Version: 2.2, Updated on 2006/04/28 at 15:46:58
;;  Generated by PSoC Designer ver 4.4  b1884 : 14 Jan, 2007
;;
;;  DESCRIPTION: FlashTemp User Module software implementation file for the
;;               22/24/27xxx PSoC family of devices.
;;
;;  NOTE: User Module APIs conform to the fastcall16 convention for marshalling
;;        arguments and observe the associated "Registers are volatile" policy.
;;        This means it is the caller's responsibility to preserve any values
;;        in the X and A registers that are still needed after the API functions
;;        returns. For Large Memory Model devices it is also the caller's 
;;        responsibility to perserve any value in the CUR_PP, IDX_PP, MVR_PP and 
;;        MVW_PP registers. Even though some of these registers may not be modified
;;        now, there is no guarantee that will remain the case in future releases.
;;-----------------------------------------------------------------------------
;;  Copyright (c) Cypress MicroSystems 2000-2003. All Rights Reserved.
;;*****************************************************************************
;;*****************************************************************************

include "FlashTemp.inc"
include "m8c.inc"
include "memory.inc"

;-----------------------------------------------
;  Global Symbols
;-----------------------------------------------
export  FlashTemp_Start
export _FlashTemp_Start
export  FlashTemp_fIsData
export _FlashTemp_fIsData
export  FlashTemp_cGetData
export _FlashTemp_cGetData
export  FlashTemp_Stop
export _FlashTemp_Stop

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;       WARNING WARNING WARNING
; The following exports are for backwards
; compatibility only and should not be used
; for new designs.
export  fFlashTemp_IsData
export _fFlashTemp_IsData
export  cFlashTemp_GetData
export _cFlashTemp_GetData
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;-----------------------------------------------
;  EQUATES
;-----------------------------------------------
bSAMPLE_SIZE:     equ  FFh  ; Number of samples to collect is 255

AREA UserModules (ROM,REL)

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: FlashTemp_Start
;
;  DESCRIPTION:
;    Powers up the PSoC Block and does everything needed
;    to start the data collection process.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: none
;
;  RETURNS:   none
;
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;          
;    Currently only the page pointer registers listed below are modified: 
;          CUR_PP
;
;  THEORY of OPERATION or PROCEDURE:
;
;   FlashTemp_Start sets the Power[1:0] bits of the analog
;   block's CR3 register. (Because the bits of CR3 for the temperature
;   block have fixed values, the setting of the other CR3 bits can be
;   assumed and a constant is used instead of a mask.)  Sets the analog
;   column interrupt to be sourced by PHI2 falling edge.
;   Turns off auto reset on the feedback cap (Fcap) so that it becomes
;   an integrator for ADC.  Loads the count variable used by the ISR
;   with the number of samples to be taken.  Initializes a data
;   accumulation variable that is incremented by the ISR.  Enables
;   interrupts and then lets the ISR handle the rest.
;   (Once data collection has been completed by the ISR, the ISR will
;   disable interrupts, reset the integrating cap and power off the
;   block.)
;
;   NOTE:  The contents of cFlashTemp_ADCData is invalid while
;          data is being collected.
;
 FlashTemp_Start:
_FlashTemp_Start:
   RAM_PROLOGUE RAM_USE_CLASS_4
   RAM_SETPAGE_CUR >FlashTemp_bADCCounter
   mov reg[FlashTemp_FlashTempCR3],(bfFLASHTEMP_CR3 | FlashTemp_bfMEDPOWER)
                                        ;set the power to Medium
   or  reg[CMP_CR0],FlashTemp_bfINT_CTRL_MASK
                                        ;set the interrupt to occur on
                                        ;   the falling edge of PHI2

   and reg[FlashTemp_FlashTempCR2],~FlashTemp_bfAUTO_ZERO
                                        ;Enable integrator
   mov [FlashTemp_bADCCounter],bSAMPLE_SIZE
                                        ;Set # of samples
   mov [FlashTemp_iADCData],>FlashTemp_iOFFSET
   mov [FlashTemp_iADCData+1],<FlashTemp_iOFFSET
                                        ;Initialize the data accumulator
   or  reg[INT_MSK0],FlashTemp_bfINT_MASK                        ;Enable interrupt
   RAM_EPILOGUE RAM_USE_CLASS_4
   ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: FlashTemp_fIsData
;
;  DESCRIPTION:
;    Returns the status of the A/D process.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: none
;
;  RETURNS:
;    A = 0xFF means it is not done.
;    A = 0x00 means it is done.
;
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;          
;    Currently only the page pointer registers listed below are modified: 
;          CUR_PP
;
;  THEORY of OPERATION or PROCEDURE:
;   The counter used in the ISR (bFlashTemp_ADCCounter) is loaded
;   with bSAMPLE_SIZE by FlashTemp_Start and counted down in the
;   ISR (FlashTemp_FlashTempInt).  When it reaches 0, the data
;   collection process is complete.  fFlashTemp_IsData returns
;   a value indicating the status of counter.
;
;   NOTE:  The contents of cFlashTemp_ADCData is invalid while
;          data is being collected.
;
 FlashTemp_fIsData:
_FlashTemp_fIsData:
 fFlashTemp_IsData:    ; For backwards compatibility only.
_fFlashTemp_IsData:    ; For backwards compatibility only.
    RAM_PROLOGUE RAM_USE_CLASS_4
    RAM_SETPAGE_CUR >FlashTemp_bADCCounter
    cmp [FlashTemp_bADCCounter],0
    jnz ClearFlag
    mov A,FFh
    ret
ClearFlag:
    mov A,0
    RAM_EPILOGUE RAM_USE_CLASS_4
    ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: FlashTemp_cGetData
;
;  DESCRIPTION:
;    Returns the results of the temperature A/D process.
;    Does not check if the data is valid.  The routine
;    fFlashTemp_IsData should be used to see if the
;    data is ready to be read.  After the data has been
;    read bFlashTemp_ADCCounter is set to
;    a non-zero value to indicate that the data is not
;    new.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: none
;
;  RETURNS:
;    A = Temperature in 8-bit 2's complement format
;
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;          
;    Currently only the page pointer registers listed below are modified: 
;          CUR_PP
;
;  THEORY of OPERATION or PROCEDURE:
;   When the ISR has completed 255 data collections, the high byte of
;   a 16-bit variable (cFlashTemp_ADCData) will contain
;   the temperature in degrees Celsius.  The upper byte of that variable
;   is read and returned.  Making bFlashTemp_ADCCounter non-zero
;   will indicate that the data is now "old".
;
 FlashTemp_cGetData:
_FlashTemp_cGetData:
 cFlashTemp_GetData:     ; For backwards compatibility only.
_cFlashTemp_GetData:     ; For backwards compatibility only.
    RAM_PROLOGUE RAM_USE_CLASS_4
    RAM_SETPAGE_CUR >FlashTemp_bADCCounter
    mov [FlashTemp_bADCCounter],bSAMPLE_SIZE
                                        ;this clears the data ready flag
    mov A,[FlashTemp_iADCData]   ;get the MSB as the data
    RAM_EPILOGUE RAM_USE_CLASS_4
    ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: FlashTemp_Stop
;
;  DESCRIPTION:
;    Powers down the PSoC block.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: none
;
;  RETURNS:   none
;
;  SIDE EFFECTS:
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;
;  THEORY of OPERATION or PROCEDURE:
;   FlashTemp_Stop sets the Power[1:0] bits of the analog
;   block's CR3 register to off and disables the column interrupt.
;   Doing this while data is being collected will result in the
;
;   NOTE:  The contents of cFlashTemp_ADCData is invalid while
;          data is being collected.
;
 FlashTemp_Stop:
_FlashTemp_Stop:
   RAM_PROLOGUE RAM_USE_CLASS_1
   mov  reg[FlashTemp_FlashTempCR3],bfFLASHTEMP_CR3   ;power down
   and  reg[INT_MSK0],~FlashTemp_bfINT_MASK           ;disable the interrupt
   and  reg[CMP_CR0],~FlashTemp_bfINT_CTRL_MASK        ; Reset bit back to default state.
   RAM_EPILOGUE RAM_USE_CLASS_1
   ret
.ENDSECTION

; End of File FlashTemp.asm
